==> cayenne-4.0.3-src.tar.gz: cayenne-4.0.3-src/cayenne-client-jetty/src/main/java/org/apache/cayenne/configuration/rop/client/ClientJettyHttpModule.java <==
/*****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 ****************************************************************/

package org.apache.cayenne.configuration.rop.client;

import org.apache.cayenne.di.Binder;
import org.apache.cayenne.di.Module;
import org.apache.cayenne.remote.ClientConnection;
import org.apache.cayenne.rop.JettyHttpClientConnectionProvider;
import org.apache.cayenne.rop.http.JettyHttpROPConnector;

/**
 * This is HTTP/1.1 implementation of ROP Client.
 * <p>
 * This module uses {@link JettyHttpROPConnector} initialized by {@link JettyHttpClientConnectionProvider}.
 */
public class ClientJettyHttpModule implements Module {

    @Override
    public void configure(Binder binder) {
        binder.bind(ClientConnection.class).toProvider(JettyHttpClientConnectionProvider.class);
    }

}

==> cayenne-4.2.3-src.tar.gz: cayenne-4.2.3-src/cayenne-client-jetty/src/main/java/org/apache/cayenne/configuration/rop/client/ClientJettyHttpModule.java <==
/*****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * <p>
 * https://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 ****************************************************************/

package org.apache.cayenne.configuration.rop.client;

import org.apache.cayenne.di.Binder;
import org.apache.cayenne.di.Module;
import org.apache.cayenne.remote.ClientConnection;
import org.apache.cayenne.rop.JettyHttpClientConnectionProvider;
import org.apache.cayenne.rop.http.JettyHttpROPConnector;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * This is HTTP/1.1 implementation of ROP Client.
 * <p>
 * This module uses {@link JettyHttpROPConnector} initialized by {@link JettyHttpClientConnectionProvider}.
 */
public class ClientJettyHttpModule implements Module {

    private static final Logger logger = LoggerFactory.getLogger(ClientJettyHttpModule.class);

    @Override
    public void configure(Binder binder) {
        logger.warn("Since 4.2 cayenne-client-jetty module was deprecated.");

        binder.bind(ClientConnection.class).toProvider(JettyHttpClientConnectionProvider.class);
    }

}
